.. metapho documentation master file, created by
   sphinx-quickstart on Fri Dec 20 15:59:20 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

MetaPho Documentation
======================================

.. mdinclude:: ../../README.md

MetaPho Manual Pages
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   metapho-manual
   notags-manual


MetaPho API Documentation
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
